#include "features.h"
#include "globals.h"

#include <iostream>

using namespace std;

extern "C"
{
#include <SDL_image.h>
}

bool is_collision(Sprite &a, Sprite &b)
{
	double left1, left2, right1, right2, top1, top2, bottom1, bottom2;
	left1 = a.getx() + a.getw() * 0.1;
	left2 = b.getx() + b.getw() * 0.1;
	top1 = a.gety() + a.geth() * 0.1;
	top2 = b.gety() + b.geth() * 0.1;

	right1 = a.getx() + a.getw() * 0.9;
	right2 = b.getx() + b.getw() * 0.9;
	bottom1 = a.gety() + a.geth() * 0.9;
	bottom2 = b.gety() + b.geth() * 0.9;

	if(bottom1 < top2 || top1 > bottom2 || right1 < left2 || left1 > right2)
	{
		return false;
	}
	return true;
}

void draw_img(SDL_Surface *img, const int x, const int y, const int w, const int h, const int x2, const int y2)
{
	SDL_Rect dest, dest2;
	if(img == NULL)
	{
		return;
	}
	dest.x = x;
	dest.y = y;
	dest2.x = x2;
	dest2.y = y2;
	dest2.w = w;
	dest2.h = h;
	SDL_BlitSurface(img, &dest2, screen, &dest);
}

void draw_img(SDL_Surface *img, const int x, const int y)
{
	SDL_Rect dest;
	if(img == NULL)
	{
		return;
	}
	dest.x = x;
	dest.y = y;
	SDL_BlitSurface(img, NULL, screen, &dest);
}

SDL_Surface *load_img(const char *file)
{
	SDL_Surface *tmp, *tmp2;
	char path[256];
	
	snprintf(path, 256, "%s%s", data_prefix, file);
	if(!(tmp = IMG_Load(path)))
	{
		cout << "Can't load \"" << path << "\"." << endl;
		throw "load_img failed!";
	}
	tmp2 = SDL_DisplayFormat(tmp);
	free_img(tmp);
	return tmp2;
}

SDL_Surface *load_img(const char *file, Uint8 r, Uint8 g, Uint8 b)
{
	SDL_Surface *tmp, *tmp2;
	char path[256];
	snprintf(path, 256, "%s%s", data_prefix, file);
	if(!(tmp = IMG_Load(path)))
	{
		cout << "Can't load \"" << path << "\"." << endl;
		throw "load_img failed!";
	}
	SDL_SetColorKey(tmp, SDL_SRCCOLORKEY, SDL_MapRGB(tmp->format, r, g, b));

	tmp2 = SDL_DisplayFormat(tmp);
	free_img(tmp);

	return tmp2;
}

void free_img(SDL_Surface *a)
{
	if(a == NULL)
	{
		return;
	}
	SDL_FreeSurface(a);
}


