#include "font.h"
#include "features.h"
#include "globals.h"

#include <iostream>

using namespace std;

BFont::BFont() : font(NULL), init_done(false)
{
}

BFont::BFont(const char *file, const int n, const bool, const bool, const bool) : font(NULL), init_done(false)
{
	init(file, n);
}

BFont::~BFont()
{
	if(font != NULL)
	{
		TTF_CloseFont(font);
	}
}

void BFont::init(const char *file, const int n, const bool bold, const bool italic, const bool underline)
{
	char path[256];
	if(is_init_done())
	{
		cout << "init already done!" << endl;
		throw "BFont:init failed!";
	}
	snprintf(path, 256, "%s%s", data_prefix, file);
	if((font = TTF_OpenFont(path, n)) == NULL)
	{
		cout << "Can't load \"" << path << "\"." << endl;
		throw "BFont:init failed!";
	}
	if(bold)
	{
		TTF_SetFontStyle(font, TTF_STYLE_BOLD);
	}
	if(italic)
	{
		TTF_SetFontStyle(font, TTF_STYLE_ITALIC);
	}
	if(underline)
	{
		TTF_SetFontStyle(font, TTF_STYLE_UNDERLINE);
	}
	init_done = true;
}

SDL_Surface *BFont::render_text(const char *t, Uint8 r, Uint8 g, Uint8 b)
{
	SDL_Color color;
	if(!is_init_done())
	{
		return NULL;
	}

	color.r = r;
	color.g = g;
	color.b = b;
	return TTF_RenderText_Blended(font, t, color);
}

bool BFont::is_init_done()
{
	return init_done;
}

Font::Font() : text(NULL), base(NULL), our_base(false)
{
	setxy(0, 0);
}

Font::Font(const char *file, const int n) : text(NULL), base(NULL), our_base(false)
{
	setxy(0, 0);
	init(file, n);
}

Font::Font(BFont &b) : text(NULL), base(NULL), our_base(false)
{
	setxy(0, 0);
	init(b);
}

Font::~Font()
{
	free_img(text);
	if(our_base)
	{
		delete base;
	}
}

void Font::init(const char *file, const int n)
{
	if(base != NULL)
	{
		cout << "init already done!" << endl;
		throw "Font::init failed!";
	}

	try
	{
		base = new BFont(file, n);
	}
	catch(...)
	{
		delete base;
		base = NULL;
		throw;
	}
	our_base = true;
}

void Font::init(BFont &b)
{
	if(base != NULL)
	{
		cout << "init already done!" << endl;
		throw "Font::init failed!";
	}
	if(!b.is_init_done())
	{
		cout << "init of base not done!" << endl;
		throw "Font::init failed!";
	}
	base = &b;
}

void Font::draw_justified()
{
	if(!is_visible())
	{
		return;
	}
	draw_img(text, getx() - getw(), gety());
}

void Font::draw_hcentered()
{
	if(!is_visible())
	{
		return;
	}
	draw_img(text, (640 / 2) - (getw() / 2), gety());
}

void Font::draw_vcentered()
{
	if(!is_visible())
	{
		return;
	}
	draw_img(text, getx(), (480 / 2) - (geth() / 2));
}

void Font::draw_centered()
{
	if(!is_visible())
	{
		return;
	}
	draw_img(text, (640 / 2) - (getw() / 2), (480 / 2) - (geth() / 2));
}

void Font::draw()
{
	if(!is_visible())
	{
		return;
	}
	draw_img(text, getx(), gety());
}

bool Font::render_text(const char *t, Uint8 r, Uint8 g, Uint8 b)
{
	if(base == NULL)
	{
		return false;
	}
	free_img(text);
	if((text = base->render_text(t, r, g, b)) == NULL)
	{
		return false;
	}
	return true;
}

int Font::geth()
{
	if(text == NULL)
	{
		return 0;
	}
	return text->h;
}

int Font::getw()
{
	if(text == NULL)
	{
		return 0;
	}
	return text->w;
}

