#include "music.h"
#include "globals.h"

#include <iostream>

using namespace std;

Music::Music() : music(NULL), volume(SDL_MIX_MAXVOLUME)
{
}

Music::Music(const char *file) : music(NULL), volume(SDL_MIX_MAXVOLUME)
{
	load(file);
}

Music::~Music()
{
	if(music != NULL)
	{
		Mix_FreeMusic(music);
	}
}

void Music::set_volume(const int i)
{
	if(i > SDL_MIX_MAXVOLUME || i < 0)
	{
		return;
	}
	volume = i;
	if(music != NULL)
	{
		Mix_VolumeMusic(volume);
	}
}

int Music::get_volume()
{
	return volume;
}

void Music::load(const char *file)
{
	char path[256];
	if(music != NULL)
	{
		Mix_FreeMusic(music);
	}
	snprintf(path, 256, "%s%s", data_prefix, file);
	if((music = Mix_LoadMUS(path)) == NULL)
	{
		cout << "Can't load \"" << path << "\"." << endl;
		throw "Music::load failed!";
	}
}

void Music::play()
{
	if(music == NULL)
	{
		return;
	}
	if(Mix_PlayingMusic())
	{
		return;
	}
	Mix_PlayMusic(music, 1);
	Mix_VolumeMusic(volume);
}


