#ifndef SPRITE_H
#define SPRITE_H

extern "C"
{
#include <SDL.h>
}

#include "xy.h"
#include "visible.h"

class BSprite
{
	public:
		BSprite();
		BSprite(const char *);
		~BSprite();
		void init(const char *);
		void reset();
		int geth();
		int getw();
		bool is_init_done();
		int get_frames();
		int get_pause(const int);
		SDL_Surface *get_image(const int);
		bool check_frame(const int);

	private:
		bool init_done;

		struct frame_struct
		{
			SDL_Surface *image;
			int pause;
		} *frame;
		int nr;
};

class Sprite : public XY<float>, public Visible
{
	public:
		Sprite();
		Sprite(const char *);
		Sprite(BSprite &);
		~Sprite();
		void init(const char *);
		void init(BSprite &);
		int getw();
		int geth();
		void set_speed(const float);
		float get_speed();
		void draw();
		void stop_anim();
		void start_anim();
		bool is_animating();
		void set_frame(const int);
		int get_frames();
		void enable_loop();
		void disable_loop();
	private:
		void first_init();

		float speed;
		int curr;
		unsigned int last_update;
		bool animating, our_base, play_loop;
		BSprite *base; 
};


#endif

